==> mythgallery_0.16.orig.tar.gz: mythgallery-0.16/i18n/mythgallery_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>IconView</name>
    <message>
        <source>Import pictures?</source>
        <translation>Bilder importieren?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>Nothing found to import</source>
        <translation>Nichts neues gefunden</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Sorry: OpenGL support not available</source>
        <translation>OpenGL Unterstützung nicht verfügbar</translation>
    </message>
    <message>
        <source>SlideShow</source>
        <translation>Diaschau</translation>
    </message>
    <message>
        <source>Rotate CW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate CCW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importieren</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds images</source>
        <translation>Verzeichnis mit Bildern</translation>
    </message>
    <message>
        <source>This directory must exist and MythGallery needs to have read permission.</source>
        <translation>Dieses Verzeichnis muß existieren und MythGallery Schreibrechte dafür besitzen.</translation>
    </message>
    <message>
        <source>Paths to import images from</source>
        <translation>Verzeichnisse für den Bildimport</translation>
    </message>
    <message>
        <source>Type of transition</source>
        <translation>Art des Übergangs</translation>
    </message>
    <message>
        <source>Type of background</source>
        <translation>Art des Hintergrunds</translation>
    </message>
    <message>
        <source>This is the number of seconds to display each picture.</source>
        <translation>Jedes Bild wird für diese Anzahl Sekunden angezeigt.</translation>
    </message>
    <message>
        <source>MythGallery Settings</source>
        <translation>MythGallery Einstellungen</translation>
    </message>
    <message>
        <source>This is a colon separated list of paths. If the path in the list is a directory, its contents will be copied. If it is an executable, it will be run.</source>
        <translation>Durch Komma getrennt Liste mit Verzeichnissen. Ist das Element in der Liste ein Verzeichnis, wird sein Inhalt kopiert. Ist es eine ausführbare Datei wird diese gestartet.</translation>
    </message>
    <message>
        <source>This is the type of transition used between pictures in slideshow mode.</source>
        <translation>Wählt die Art des Übergangs zwischen zwei Bildern im Diaschau Modus.</translation>
    </message>
    <message>
        <source>This is the type of background for each picture in single view mode.</source>
        <translation>Die Art des Hintergrunds für Bilder in der Einzelanzeige.</translation>
    </message>
    <message>
        <source>Slideshow Delay</source>
        <translation>Anzeigedauer im Diaschaumodus</translation>
    </message>
    <message>
        <source>Use OpenGL transitions</source>
        <translation>Nutze OpenGL Übergänge</translation>
    </message>
    <message>
        <source>Check this to enable OpenGL based slideshow transitions</source>
        <translation>Aktiviert OpenGL basierende Übergänge für den Diaschaumodus</translation>
    </message>
    <message>
        <source>Type of OpenGL transition</source>
        <translation>Art des OpenGL Übergangs</translation>
    </message>
    <message>
        <source>This is the type of OpenGL transition used between pictures in slideshow mode.</source>
        <translation>Bestimmt welcher OpenGL Übergang im Diaschaumodus verwendet wird.</translation>
    </message>
    <message>
        <source>Gallery Directory does not exist or is unreadable.</source>
        <translation>Bilderverzeichnis existiert nicht oder ist nicht lesbar.</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>SingleView</name>
    <message>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation>Pixelzahl</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation>Drehwinkel</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation>pixel</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation>Megapixel</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>Grad</translation>
    </message>
    <message>
        <source>Created: </source>
        <translation>Erzeugt:</translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation>Geändert:</translation>
    </message>
    <message>
        <source>Folder: </source>
        <translation>Verzeichnis:</translation>
    </message>
</context>
</TS>

==> mythgallery_0.17.orig.tar.gz: mythgallery-0.17/i18n/mythgallery_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>GLSingleView</name>
    <message>
        <source>Folder: </source>
        <translation>Verzeichnis: </translation>
    </message>
    <message>
        <source>Created: </source>
        <translation>Erzeugt: </translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation>Geändert: </translation>
    </message>
    <message>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation>Pixelanzahl</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation>Megapixel</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation>Drehung</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>°</translation>
    </message>
</context>
<context>
    <name>IconView</name>
    <message>
        <source>Import pictures?</source>
        <translation>Bilder importieren?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>Nothing found to import</source>
        <translation>Nichts Neues gefunden</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Sorry: OpenGL support not available</source>
        <translation>OpenGL-Unterstützung nicht verfügbar</translation>
    </message>
    <message>
        <source>SlideShow</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>Rotate CW</source>
        <translation>90° drehen</translation>
    </message>
    <message>
        <source>Rotate CCW</source>
        <translation>270° drehen</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importieren</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Zufall</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds images</source>
        <translation>Verzeichnis mit Bildern</translation>
    </message>
    <message>
        <source>This directory must exist and MythGallery needs to have read permission.</source>
        <translation>Dieses Verzeichnis muß existieren und MythGallery Leserechte dafür besitzen.</translation>
    </message>
    <message>
        <source>Paths to import images from</source>
        <translation>Verzeichnisse für den Bildimport</translation>
    </message>
    <message>
        <source>Type of transition</source>
        <translation>Art des Übergangs</translation>
    </message>
    <message>
        <source>Type of background</source>
        <translation>Art des Hintergrunds</translation>
    </message>
    <message>
        <source>This is the number of seconds to display each picture.</source>
        <translation>Jedes Bild wird für diese Anzahl Sekunden angezeigt.</translation>
    </message>
    <message>
        <source>MythGallery Settings</source>
        <translation>MythGallery Einstellungen</translation>
    </message>
    <message>
        <source>This is a colon separated list of paths. If the path in the list is a directory, its contents will be copied. If it is an executable, it will be run.</source>
        <translation>Eine durch Kommas getrennte Liste von Verzeichnissen. Ist das Element in der Liste ein Verzeichnis, wird sein Inhalt kopiert. Ist es eine ausführbare Datei wird diese gestartet.</translation>
    </message>
    <message>
        <source>This is the type of transition used between pictures in slideshow mode.</source>
        <translation>Wählt die Art des Übergangs zwischen zwei Bildern im Diashow Modus.</translation>
    </message>
    <message>
        <source>This is the type of background for each picture in single view mode.</source>
        <translation>Die Art des Hintergrunds für Bilder in der Einzelanzeige.</translation>
    </message>
    <message>
        <source>Slideshow Delay</source>
        <translation>Anzeigedauer im Diashow-Modus</translation>
    </message>
    <message>
        <source>Use OpenGL transitions</source>
        <translation>Nutze OpenGL-Übergänge</translation>
    </message>
    <message>
        <source>Check this to enable OpenGL based slideshow transitions</source>
        <translation>Aktiviert auf OpenGL basierende Übergänge für den Diashow-Modus.</translation>
    </message>
    <message>
        <source>Type of OpenGL transition</source>
        <translation>Art des OpenGL-Übergangs</translation>
    </message>
    <message>
        <source>This is the type of OpenGL transition used between pictures in slideshow mode.</source>
        <translation>Bestimmt welcher OpenGL-Übergang im Diashow-Modus verwendet wird.</translation>
    </message>
    <message>
        <source>Gallery Directory does not exist or is unreadable.</source>
        <translation>Bilderverzeichnis existiert nicht oder ist nicht lesbar.</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Command run to display movie files</source>
        <translation>Befehl zum Abspielen von Filmen</translation>
    </message>
    <message>
        <source>This command is executed whenever a movie file is selected</source>
        <translation>Dieser Befehl wird ausgeführt, wenn ein Film ausgewählt wird</translation>
    </message>
</context>
<context>
    <name>SingleView</name>
    <message>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation>Pixelanzahl</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation>Drehung</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation>Megapixel</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>°</translation>
    </message>
    <message>
        <source>Created: </source>
        <translation>Erzeugt: </translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation>Geändert: </translation>
    </message>
    <message>
        <source>Folder: </source>
        <translation>Verzeichnis: </translation>
    </message>
</context>
</TS>
